@@ -2,13 +2,14 @@ use serde::de::DeserializeOwned;
 use serde::Serialize;
 use std::marker::PhantomData;
 
+use crate::helpers::query_raw;
 use crate::keys::PrimaryKey;
 #[cfg(feature = "iterator")]
 use crate::keys::{EmptyPrefix, Prefixer};
 use crate::path::Path;
 #[cfg(feature = "iterator")]
 use crate::prefix::{Bound, Prefix};
-use cosmwasm_std::{StdError, StdResult, Storage};
+use cosmwasm_std::{from_slice, Addr, QuerierWrapper, StdError, StdResult, Storage};
 
 #[derive(Debug, Clone)]
 pub struct Map<'a, K, T> {
@@ -66,6 +67,12 @@ where
         self.key(k).may_load(store)
     }
 
+    /// has returns true or false if any data is at this key, without parsing or interpreting the
+    /// contents.
+    pub fn has(&self, store: &dyn Storage, k: K) -> bool {
+        self.key(k).has(store)
+    }
+
     /// Loads the data, perform the specified action, and store the result
     /// in the database. This is shorthand for some common sequences, which may be useful.
     ///
@@ -77,6 +84,23 @@ where
     {
         self.key(k).update(store, action)
     }
+
+    /// If you import the proper Map from the remote contract, this will let you read the data
+    /// from a remote contract in a type-safe way using WasmQuery::RawQuery
+    pub fn query(
+        &self,
+        querier: &QuerierWrapper,
+        remote_contract: Addr,
+        k: K,
+    ) -> StdResult<Option<T>> {
+        let key = self.key(k).storage_key.into();
+        let result = query_raw(querier, remote_contract, key)?;
+        if result.is_empty() {
+            Ok(None)
+        } else {
+            from_slice(&result).map(Some)
+        }
+    }
 }
 
 // short-cut for simple keys, rather than .prefix(()).range(...)
@@ -199,6 +223,33 @@ mod test {
         assert_eq!(None, john.may_load(&store).unwrap());
     }
 
+    #[test]
+    fn existence() {
+        let mut store = MockStorage::new();
+
+        // set data in proper format
+        let data = Data {
+            name: "John".to_string(),
+            age: 32,
+        };
+        PEOPLE.save(&mut store, b"john", &data).unwrap();
+
+        // set and remove it
+        PEOPLE.save(&mut store, b"removed", &data).unwrap();
+        PEOPLE.remove(&mut store, b"removed");
+
+        // invalid, but non-empty data
+        store.set(&PEOPLE.key(b"random"), b"random-data");
+
+        // any data, including invalid or empty is returned as "has"
+        assert!(PEOPLE.has(&store, b"john"));
+        assert!(PEOPLE.has(&store, b"random"));
+
+        // if nothing was written, it is false
+        assert!(!PEOPLE.has(&store, b"never-writen"));
+        assert!(!PEOPLE.has(&store, b"removed"));
+    }
+
     #[test]
     fn composite_keys() {
         let mut store = MockStorage::new();
